@@ -703,7 +703,7 @@ get_fb_info (SunOneConnection *so_cnc, const char *user, const char *calid, time
 			icalcomponent_add_property (fb, prop);
 
 		*freebusy = g_list_append (*freebusy,
-				icalcomponent_as_ical_string (fb));
+				icalcomponent_as_ical_string_r (fb));
 	}
 
 	icalcomponent_free (icalcomp);
